summaryrefslogtreecommitdiff
path: root/src/conf_mode/interfaces-vxlan.py
diff options
context:
space:
mode:
authorChristian Poessinger <christian@poessinger.com>2020-03-27 17:03:24 +0100
committerChristian Poessinger <christian@poessinger.com>2020-03-28 11:28:56 +0100
commit09a0cecf02972fa9019fcfd900c50b27797f40e2 (patch)
treed58db577283626a93c2680ec9e3aa7b9cfea0e25 /src/conf_mode/interfaces-vxlan.py
parentadc09e4ecaf91bc93b3994eac4f2f2ac2786a1c7 (diff)
downloadvyos-1x-09a0cecf02972fa9019fcfd900c50b27797f40e2.tar.gz
vyos-1x-09a0cecf02972fa9019fcfd900c50b27797f40e2.zip
ipv6: T1831: migrate autoconf node
Autoconfigure addresses using Prefix Information in Router Advertisements.
Diffstat (limited to 'src/conf_mode/interfaces-vxlan.py')
-rwxr-xr-xsrc/conf_mode/interfaces-vxlan.py9
1 files changed, 8 insertions, 1 deletions
diff --git a/src/conf_mode/interfaces-vxlan.py b/src/conf_mode/interfaces-vxlan.py
index e1d31369e..294864bc1 100755
--- a/src/conf_mode/interfaces-vxlan.py
+++ b/src/conf_mode/interfaces-vxlan.py
@@ -37,6 +37,7 @@ default_config_data = {
'ip_enable_arp_announce': 0,
'ip_enable_arp_ignore': 0,
'ip_proxy_arp': 0,
+ 'ipv6_autoconf': 0,
'ipv6_forwarding': 1,
'ipv6_dup_addr_detect': 1,
'link': '',
@@ -105,6 +106,10 @@ def get_config():
if conf.exists('ip enable-proxy-arp'):
vxlan['ip_proxy_arp'] = 1
+ # Enable acquisition of IPv6 address using stateless autoconfig (SLAAC)
+ if conf.exists('ipv6 address autoconf'):
+ vxlan['ipv6_autoconf'] = 1
+
# Disable IPv6 forwarding on this interface
if conf.exists('ipv6 disable-forwarding'):
vxlan['ipv6_forwarding'] = 0
@@ -211,7 +216,9 @@ def apply(vxlan):
v.set_arp_ignore(vxlan['ip_enable_arp_ignore'])
# Enable proxy-arp on this interface
v.set_proxy_arp(vxlan['ip_proxy_arp'])
- # Disable IPv6 forwarding on this interface
+ # IPv6 address autoconfiguration
+ v.set_ipv6_autoconf(vxlan['ipv6_autoconf'])
+ # IPv6 forwarding
v.set_ipv6_forwarding(vxlan['ipv6_forwarding'])
# IPv6 Duplicate Address Detection (DAD) tries
v.set_ipv6_dad_messages(vxlan['ipv6_dup_addr_detect'])